@@ -6,6 +6,7 @@ os.chdir('/Users/AnQiuPing/Documents/Python/HfCh6Levi')
 '''this function is used to read data into a list from a specific file'''
 '''version2: add more function to enable this function to return processed data with the format of Dict rathen than unprocessed List'''
 '''version3: using Class to get the top 3 times rather than Dict'''
+'''version4: add two fuctions called addTime() and addTimes()'''
 class Athlete:
     def __init__(self, a_name, a_bod=None, a_times=[]):
         self.name = a_name
@@ -16,6 +17,13 @@ class Athlete:
         '''return the sorted result for the top 3 items from the list'''
         return sorted(set([sanitize(t) for t in self.times]))[0:3]
 
+    def addTime(self, time):
+        self.times.append(time)
+
+    def addTimeList(self, timeList):
+        '''to enlarge a list by another list, extend() can be used'''
+        self.times.extend(timeList)
+
 def get_coach_data(file_name):
     try:
         with open(file_name) as file_object:
@@ -68,6 +76,17 @@ def pop():
     julie = get_coach_data('julie2.txt')
     mikey = get_coach_data('mikey2.txt')
 
+    levi = Athlete('Levi',)
+    levi.addTime('2.01')
+    print(levi.name + " 's time is: " + str(levi.top3()))
+
+    bobby = Athlete('bobby')
+    bobby.addTimeList(['1.1', '1.2', '1.3'])
+    print(bobby.name + " 's time are: " + str(levi.top3()))
+
+    print(sarah.name + " 's updated fatest times are: " + str(sarah.top3()))
+    print(james.name + " 's updated fatest times are: " + str(james.top3()))
+    
     '''version2: now using the refined Dict keys to display the desired results'''
     '''version3: using Class to get the top 3 times rather than Dict'''
     '''
